pub struct Config {
pub timeout: usize,
pub redis_namespace: String,
pub repeat_on_timeout: bool,
pub retry_count_limit: u32,
pub worker_count: usize,
pub redis_url: String,
}Expand description
Configuration options used throughout Robin.
The normal way to construct a Config is through the Default implementation.
Afterwards you can tweak the values you need.
let mut config = Config::default();
config.worker_count = 10;
assert_eq!(config.worker_count, 10);
assert_eq!(config.timeout, 30);Fields
timeout: usizeThe number of seconds the worker will block while waiting for a new job to be enqueued. By default workers will retry after the timeout is hit, so you shouldn’t need to configure this.
redis_namespace: StringNamespace used for all Redis values.
repeat_on_timeout: boolWhether or not to repeat looking for jobs when the timeout is hit. This
defaults to true and should probably remain that way.
This is used when testing Robin internally.
retry_count_limit: u32The maximum number of times a job will be retried. After that it will discarded.
worker_count: usizeThe number of worker threads to spawn. Each thread will have its own Redis connection, so make sure you have enough connections available. Defaults to the number of CPUs your machine has.
redis_url: StringThe URL that will be used to connect to Redis.